==> jc-1.4.0.tar.gz: javax/security/auth/AuthPermission.h <==
// public final class javax.security.auth.AuthPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class f806111abb01739a javax_security_auth_AuthPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_javax_security_auth_AuthPermission_H_
#define _JC_javax_security_auth_AuthPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_AuthPermission$sub_refs	_jc_javax_security_auth_AuthPermission$sub_refs;
typedef struct _jc_javax_security_auth_AuthPermission$sub_nonrefs	_jc_javax_security_auth_AuthPermission$sub_nonrefs;
typedef struct _jc_javax_security_auth_AuthPermission$refs	_jc_javax_security_auth_AuthPermission$refs;
typedef struct _jc_javax_security_auth_AuthPermission$nonrefs	_jc_javax_security_auth_AuthPermission$nonrefs;
typedef struct _jc_javax_security_auth_AuthPermission$object	_jc_javax_security_auth_AuthPermission$object;

typedef const struct _jc_javax_security_auth_AuthPermission$vmethods	_jc_javax_security_auth_AuthPermission$vmethods;
typedef const struct _jc_javax_security_auth_AuthPermission$vtable	_jc_javax_security_auth_AuthPermission$vtable;
typedef const struct _jc_javax_security_auth_AuthPermission$vtype	_jc_javax_security_auth_AuthPermission$vtype;

// Constructors
extern void _jc_javax_security_auth_AuthPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_AuthPermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_AuthPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_AuthPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_security_auth_AuthPermission$vmethods {
};

// Vtable
struct _jc_javax_security_auth_AuthPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_javax_security_auth_AuthPermission$vmethods	javax_security_auth_AuthPermission;
};

// Vtype
struct _jc_javax_security_auth_AuthPermission$vtype {
	_jc_type			type;
	_jc_javax_security_auth_AuthPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_AuthPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_AuthPermission$refs {
    _jc_javax_security_auth_AuthPermission$sub_refs	javax_security_auth_AuthPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_AuthPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_AuthPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_javax_security_auth_AuthPermission$sub_nonrefs	javax_security_auth_AuthPermission;
};

// Object instance structure
struct _jc_javax_security_auth_AuthPermission$object {
	_jc_javax_security_auth_AuthPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_AuthPermission$vtype	*vtype;
	_jc_javax_security_auth_AuthPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_AuthPermission$vtype _jc_javax_security_auth_AuthPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_AuthPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_AuthPermission$class_object;

#endif	/* _JC_javax_security_auth_AuthPermission_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/AuthPermission.h <==
// public final class javax.security.auth.AuthPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class f806111abb01739a javax_security_auth_AuthPermission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_javax_security_auth_AuthPermission_H_
#define _JC_javax_security_auth_AuthPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_AuthPermission$sub_refs	_jc_javax_security_auth_AuthPermission$sub_refs;
typedef struct _jc_javax_security_auth_AuthPermission$sub_nonrefs	_jc_javax_security_auth_AuthPermission$sub_nonrefs;
typedef struct _jc_javax_security_auth_AuthPermission$refs	_jc_javax_security_auth_AuthPermission$refs;
typedef struct _jc_javax_security_auth_AuthPermission$nonrefs	_jc_javax_security_auth_AuthPermission$nonrefs;
typedef struct _jc_javax_security_auth_AuthPermission$object	_jc_javax_security_auth_AuthPermission$object;

typedef const struct _jc_javax_security_auth_AuthPermission$vmethods	_jc_javax_security_auth_AuthPermission$vmethods;
typedef const struct _jc_javax_security_auth_AuthPermission$vtable	_jc_javax_security_auth_AuthPermission$vtable;
typedef const struct _jc_javax_security_auth_AuthPermission$vtype	_jc_javax_security_auth_AuthPermission$vtype;

// Constructors
extern void _jc_javax_security_auth_AuthPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_AuthPermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_AuthPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_AuthPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_auth_AuthPermission$vmethods {
};

// Vtable
struct _jc_javax_security_auth_AuthPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_javax_security_auth_AuthPermission$vmethods	javax_security_auth_AuthPermission;
};

// Vtype
struct _jc_javax_security_auth_AuthPermission$vtype {
	_jc_type			type;
	_jc_javax_security_auth_AuthPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_AuthPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_AuthPermission$refs {
    _jc_javax_security_auth_AuthPermission$sub_refs	javax_security_auth_AuthPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_AuthPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_AuthPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_javax_security_auth_AuthPermission$sub_nonrefs	javax_security_auth_AuthPermission;
};

// Object instance structure
struct _jc_javax_security_auth_AuthPermission$object {
	_jc_javax_security_auth_AuthPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_AuthPermission$vtype	*vtype;
	_jc_javax_security_auth_AuthPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_AuthPermission$vtype _jc_javax_security_auth_AuthPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_AuthPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_AuthPermission$class_object;

#endif	/* _JC_javax_security_auth_AuthPermission_H_ */
